pub fn normalize_path_under(
path: impl AsRef<Path>,
root: impl AsRef<Path>,
) -> Option<PathBuf>Expand description
Normalize path, returning it when it remains strictly under a non-empty root.
This comparison is lexical and does not resolve symlinks. The returned path is normalized, and
equality with root is rejected.